@@ -32,6 +32,7 @@
 #include <util/log.h>
 #include <settings.h>
 #include <interfaces/torrentinterface.h>
+#include <interfaces/torrentactivityinterface.h>
 #include <torrent/queuemanager.h>
 #include "core.h"
 #include "trayicon.h"
@@ -39,7 +40,6 @@
 #include <kactioncollection.h>
 
 
-
 using namespace bt;
 
 namespace kt
@@ -102,8 +102,10 @@ namespace kt
 		if (status_notifier_item)
 			return;
 		
-		menu = new KMenu(0);
-		KActionCollection* ac = mwnd->actionCollection();
+		status_notifier_item = new KStatusNotifierItem(mwnd);
+		
+		menu = status_notifier_item->contextMenu();
+	
 		max_upload_rate = new SetMaxRate(core,SetMaxRate::UPLOAD,menu);
 		max_upload_rate->setTitle(i18n("Set max upload speed"));
 		max_download_rate = new SetMaxRate(core,SetMaxRate::DOWNLOAD,menu);
@@ -111,20 +113,25 @@ namespace kt
 		menu->addMenu(max_download_rate);
 		menu->addMenu(max_upload_rate);
 		menu->addSeparator();
+		
+		KActionCollection* ac = mwnd->getTorrentActivity()->part()->actionCollection();
 		menu->addAction(ac->action("start_all"));
 		menu->addAction(ac->action("stop_all"));
 		menu->addAction(ac->action("queue_suspend"));
 		menu->addSeparator();
+		
+		ac = mwnd->actionCollection();
 		menu->addAction(ac->action("paste_url"));
 		menu->addAction(ac->action(KStandardAction::name(KStandardAction::Open)));
 		menu->addSeparator();
 		menu->addAction(ac->action(KStandardAction::name(KStandardAction::Preferences)));
 		menu->addSeparator();
 		
-		status_notifier_item = new KStatusNotifierItem(mwnd);
+		
 		status_notifier_item->setIconByName("ktorrent");
 		status_notifier_item->setCategory(KStatusNotifierItem::ApplicationStatus);
 		status_notifier_item->setStatus(KStatusNotifierItem::Active);
+		status_notifier_item->setStandardActionsEnabled(true);
 		status_notifier_item->setContextMenu(menu);
 		if (queue_suspended)
 			status_notifier_item->setOverlayIconByName("kt-pause");
