@@ -30,6 +30,7 @@
 #include "downloadedchunkbar.h"
 #include "availabilitychunkbar.h"
 #include "statustab.h"
+#include "settings.h"
 		
 using namespace bt;
 
@@ -98,7 +99,14 @@ namespace kt
 		if (curr_tc)
 		{
 			type->setText(tc->getStats().priv_torrent ? i18n("Private") : i18n("Public"));
-			comments->setText(tc->getComments());
+
+			// Don't allow multiple lines in the comments field
+			QString text = tc->getComments();
+			if (text.contains("\n"))
+				comments->setText(text.replace("\n"," "));
+			else
+				comments->setText(text);
+
 			float ratio = curr_tc->getMaxShareRatio();
 			if(ratio > 0)
 			{
@@ -158,7 +166,7 @@ namespace kt
 		if (!time_limit->hasFocus())
 			maxSeedTimeUpdate();
 		
-		share_ratio->setText(QString("<font color=\"%1\">%2</font>").arg(ratio <= 0.8 ? "#ff0000" : "#1c9a1c").arg(KGlobal::locale()->formatNumber(ratio,2)));
+		share_ratio->setText(QString("<font color=\"%1\">%2</font>").arg(ratio <= Settings::greenRatio() ? "#ff0000" : "#1c9a1c").arg(KGlobal::locale()->formatNumber(ratio,2)));
 	
 		Uint32 secs = curr_tc->getRunningTimeUL(); 
 		if (secs == 0)
